* project: economic inequality and democratic support (JOP)
* file name: JOP2.do
* What this do-file does: after imputation (see JOP1.do), managing the data and analysis

**********************************************************************************************

* Task V: post-AMELIA
** once you are done with the imputation, /// 
you will have the imputed data in the very directory where the pre-imputation data are saved.
** That is, you will have amelia-imp1 through amelia-imp5, all of which are .csv files.

* now importing them into stata
* for some reason, in the first variable 'my157', 4 "NA" observations appear.
* and, since I set all variables ordinal or nominal, they are string variables.
* so I drop those 4 observations and convert string variables into numeric ones.
* I also re-generate the composite indices such as 'democratic support' (sa) and ///
'confidence in institution' (instconf) using the imputed data.


cd "$data"
local version "1 2 3 4 5"
foreach a of local version {
clear
insheet using "pre_impute-imp`a'.csv" 
drop if my157 == "NA"  
destring, replace
gen antiauth=my154 + my156
gen support = my157 + my163
gen sa = support + antiauth
gen instconf = (natgov + party + parl + civil)
sort id
save namelia`a', replace
}


**********************************************************************************************
Task VI: finalizing the data
* task: finishing the data
* 1. we take care of a few missing values for Gini
* 2. we generate 5 variables each of which is the imputed dataset merged with country-level variables.
* 3. we generate all the necessary variables including interaction terms.


**********************************************************************
*1


* since  gini_net variable is missing for the following four countries ///
  I use the values in the closest year.
* Observations for Puerto Rico are dropped as national level data for it is almost totally unavialable (n=720).

clear
cd "$data"

use master_1

* Japan
replace gini_net = 28.85427	if country == "Japan"
replace gini_ne1 = 1.474727	if country == "Japan"
replace gini_gro = 42.71331	if country == "Japan"
replace gini_gr1 = 2.965256   if country == "Japan"

* Morocco, code == 122 (1999)
replace gini_net = 38.69249	if code == 122 & year==2001
replace gini_ne1 = 3.144238	if code == 122 & year==2001
replace gini_gro = 52.60931	if code == 122 & year==2001
replace gini_gr1 = 6.252888   if code == 122 & year==2001

* South Africa, code == 162 (2000)
replace gini_net = 55.16838	if code == 162 & year==2001
replace gini_ne1 = 4.310034	if code == 162 & year==2001
replace gini_gro = 75.36595	if code == 162 & year==2001
replace gini_gr1 = 8.150951   if code == 162 & year==2001

* Zimbabwe, code==204 (1995)
replace gini_net = 67.84215	if code == 204 & year==2001
replace gini_ne1 = 4.016936	if code == 204 & year==2001
replace gini_gro = 87.80943	if code == 204 & year==2001
replace gini_gr1 = 3.712578   if code == 204 & year==2001

* Algeria, code == 3(1995)
replace gini_net = 34.80802	if code == 3 & year == 2002
replace gini_ne1 = 2.537817	if code == 3 & year == 2002
replace gini_gro = 47.32476	if code == 3 & year == 2002
replace gini_gr1 = 5.73974    if code == 3 & year == 2002

* among these countries, Japan is the only one in our sample.


*2.

* merging the imputed data with other variables (so we'll have 5+1 datasets: amelia1 - 5 plus the original)
* merging variable here is "id"

* first we drop all individual level variables (but the id variable) from our master dataset such that we have country-level-only dataset for all the observations.

drop my157 - income
sort id
save master_ready_1, replace
* this is the dataset where all the individual variables but the _id_ variable are dropped. 
* again, this is to be merged with the imputed ones.
* now we generate 5 dataset using each of the 5 imputed datsets

local version "1 2 3 4 5"

foreach a of local version {
clear
use master_ready_1
merge id using namelia`a'
drop if code == 319
drop _merge
sort id
save final`a', replace
}

* now putting them altogether such that we have 1 original dataset and 5 imputed datasets in one single file.
* using _mimstack_ we also let Stata know that which dataset is which.


clear
cd "$data"
use master_1
sort id
save final0, replace
mimstack, m(5) sortorder(id) istub(final) clear
sort id
save ready1, replace

*3. generating the variables needed for analysis (interaction terms, for example)


*3-1. interaction terms and other variables

clear
use ready1

gen income_gini_net = gini_net*income
gen class_gini_net = gini_net*class
gen econsat_gini_net = gini_net*econsat


* regional dummy variables
gen LA = 0
recode LA 0=1 if region == 3
label variable LA "Latin America == 1"
gen EE = 0
recode EE 0=1 if region == 4
label variable EE "Eastern Europe == 1"


* age of democracy (since the age data is seriously skewed, it seems just imperative that we log them)
gen logage = log(agedem)
label variable logage "log(agedem=age of democracy_aclp)"

tab region, gen(re)
label variable re1 "Africa"
label variable re2 "Asia"
label variable re3 "Latin America"
label variable re4 "Eastern Europe"
label variable re5 "Middle East"
sort id

save ready2, replace

****************************************************************************
****************************************************************************

*3-2. generating "new" income variable

*** One of the reviewers argued that the income variable in WVS (x047) is not cross-nationally comparable
**** and suggested instead to create an percentile variable such that ///
the distribution of the income variable is similar across countries

clear
cd "$data"

use ready2

gen match3 = match*10 + _mj
label variable match3 "country-year + imputation number"
* doing this to get the exact numbers. I don't think it matters if we used 'match' in lieu of 'match3' though.

sort match3
by match3: egen pincome1 = pctile(income), p(20)
by match3: egen pincome2 = pctile(income), p(40)
by match3: egen pincome3 = pctile(income), p(60)
by match3: egen pincome4 = pctile(income), p(80)

gen pct_income = .
recode pct_income .=1 if income <= pincome1
recode pct_income .=2 if income > pincome1 & income <= pincome2
recode pct_income .=3 if income > pincome2 & income <= pincome3
recode pct_income .=4 if income > pincome3 & income <= pincome4
recode pct_income .=5 if income > pincome4 

* to visually demonstrate
*histogram pct_income if democracy==1 & _mj==1, by(match) bin(5) name(hist_pct_income)
* graph bar pct_income if democracy==1, over(match)
* graph bar income if democracy==1, over(match)

* don't forget the interaction term
gen pct_gini = pct_income*gini_net

save ready3, replace


****************************************************************************
****************************************************************************


* 3-3. historical change of Gini

clear
cd "$data"
use gini12
sort match
save gini12, replace

use cheibub
sort match
merge match using gini12
drop _merge

keep if democracy==1
gen demotran = 0
recode demotran 0=1 if agedem==1
sort code year
by code: gen temp1 = sum(demotran)
gen code2 = code*10 + temp1
drop if gini_net==.

sort code2 year
*"minyear" provides the first year in a country/democracy period for which GINI data exists
by code2: egen minyear = min(year)
xtset code year
keep country year democracy agedem code match gini_net demotran temp1 code2 minyear

*Generate variabel with GINI data only for democratic transition year
gen temp3 = year-minyear
gen temp4 = gini_net
replace temp4 = 0 if temp3>0

*"hdgini" is decrease in GINI coefficients since transition year
sort code2 year
by code2: egen base = max(temp4)
gen hdgini = base - gini_net

keep country year match hdgini
sort match
save hdgini, replace
label data "decrease in Gini since democratization"

clear
use ready3
sort match

merge match using hdgini

drop _merge
sort match

*3-4. group mean centering all the level-1 variables ///
:pct_income income econsat class age male instconf interest trust edu ideo retpol

sort match3

local var "pct_income income econsat class age male polexp current instconf interest trust edu ideo retpol"
foreach X of local var {

by match3: egen m_`X' = mean(`X')
gen c_`X' = `X' - m_`X' 
label variable c_`X' "group-mean centered, `X' "
}



*now interaction terms

gen gini_c_pct = c_pct_income*gini_net
gen gini_c_income = c_income*gini_net
gen gini_c_econsat = c_econsat*gini_net
gen gini_c_class = c_class*gini_net

gen hgini_c_pct = c_pct_income*hdgini
gen hgini_c_income = c_income*hdgini
gen hgini_c_econsat = c_econsat*hdgini
gen hgini_c_class = c_class*hdgini

replace gini5=gini5 - gini_net
replace gini10=gini10 - gini_net

gen gini5_c_pct = c_pct_income*gini5
gen gini5_c_income = c_income*gini5
gen gini5_c_econsat = c_econsat*gini5
gen gini5_c_class = c_class*gini5

gen gini10_c_pct = c_pct_income*gini10
gen gini10_c_income = c_income*gini10
gen gini10_c_econsat = c_econsat*gini10
gen gini10_c_class = c_class*gini10

gen gini2_c_income = c_income*gini_bes
gen gini2_c_econsat = c_econsat*gini_bes
gen gini2_c_class = c_class*gini_bes


save analysis, replace


**********************************************************************************************


* Task VII: Analysis

clear
capture log close
log using reg_table_1_2, replace

cd "$data"
use analysis

mim, storebv: xtmixed sa gini_net c_income  c_age c_male c_instconf c_interest /// 
   c_trust c_edu   c_ideo c_retpol || match: if democracy==1 , cov(unstructured) mle 
outreg2 using reg_table1, bdec(3) tdec(3) rdec(3)  ///
alpha(.01, .05, .1) word replace

mim, storebv: xtmixed sa gini_net c_econsat  c_age c_male c_instconf c_interest /// 
   c_trust c_edu   c_ideo c_retpol || match: if democracy==1 , cov(unstructured) mle 
outreg2 using reg_table1, bdec(3) tdec(3) rdec(3)  ///
alpha(.01, .05, .1) word append

mim, storebv: xtmixed sa gini_net c_class  c_age c_male c_instconf c_interest /// 
   c_trust c_edu   c_ideo c_retpol || match: if democracy==1 , cov(unstructured) mle 
outreg2 using reg_table1, bdec(3) tdec(3) rdec(3)  ///
alpha(.01, .05, .1) word append

mim, storebv: xtmixed sa gini_net c_income gini_c_income c_age c_male c_instconf c_interest /// 
   c_trust c_edu   c_ideo c_retpol || match: c_income if democracy==1 , cov(unstructured) mle
outreg2 using reg_table1, bdec(3) tdec(3) rdec(3)  ///
alpha(.01, .05, .1) word append

mim, storebv: xtmixed sa gini_net c_econsat gini_c_econsat c_age c_male c_instconf c_interest ///
   c_trust c_edu   c_ideo c_retpol || match: c_econsat if democracy==1 , cov(unstructured) mle
outreg2 using reg_table1, bdec(3) tdec(3) rdec(3)  ///
alpha(.01, .05, .1) word append

mim, storebv: xtmixed sa gini_net c_class gini_c_class c_age c_male c_instconf c_interest ///
   c_trust c_edu   c_ideo c_retpol || match: c_class if democracy==1 , cov(unstructured) mle
outreg2 using reg_table1, bdec(3) tdec(3) rdec(3)  ///
alpha(.01, .05, .1) word append

shellout using "reg_table1.rtf"



mim, storebv: xtmixed sa gini_net c_income  c_age c_male c_instconf c_interest /// 
   c_trust c_edu   c_ideo c_retpol gdpgro polity2 lgdppc LA EE logage || match: if democracy==1 , cov(unstructured) mle
      outreg2 using reg_table2, bdec(3) tdec(3) rdec(3)  ///
alpha(.01, .05, .1) word replace

mim, storebv: xtmixed sa gini_net c_econsat c_age c_male c_instconf c_interest ///
   c_trust c_edu   c_ideo c_retpol gdpgro polity2 lgdppc LA EE logage || match: if democracy==1 , cov(unstructured) mle
         outreg2 using reg_table2, bdec(3) tdec(3) rdec(3)  ///
alpha(.01, .05, .1) word append

mim, storebv: xtmixed sa gini_net c_class  c_age c_male c_instconf c_interest ///
   c_trust c_edu   c_ideo c_retpol gdpgro polity2 lgdppc LA EE logage || match: if democracy==1 , cov(unstructured) mle
            outreg2 using reg_table2, bdec(3) tdec(3) rdec(3)  ///
alpha(.01, .05, .1) word append

mim, storebv: xtmixed sa gini_net c_income gini_c_income c_age c_male c_instconf c_interest /// 
   c_trust c_edu   c_ideo c_retpol gdpgro polity2 lgdppc LA EE logage || match: c_income if democracy==1 , cov(unstructured) mle
            outreg2 using reg_table2, bdec(3) tdec(3) rdec(3)  ///
alpha(.01, .05, .1) word append

mim, storebv: xtmixed sa gini_net c_econsat gini_c_econsat c_age c_male c_instconf c_interest ///
   c_trust c_edu   c_ideo c_retpol gdpgro polity2 lgdppc LA EE logage || match: c_econsat if democracy==1 , cov(unstructured) mle
            outreg2 using reg_table2, bdec(3) tdec(3) rdec(3)  ///
alpha(.01, .05, .1) word append

mim, storebv: xtmixed sa gini_net c_class gini_c_class c_age c_male c_instconf c_interest ///
   c_trust c_edu   c_ideo c_retpol gdpgro polity2 lgdppc LA EE logage || match: c_class if democracy==1 , cov(unstructured) mle
            outreg2 using reg_table2, bdec(3) tdec(3) rdec(3)  ///
alpha(.01, .05, .1) word append


shellout using "reg_table2.rtf"


* How we generated Figure 3.
** since there is no canned command to generate marginal effect graphs when using "mim:", ///
we instead used "mim: lincom" to get the marginal effect of Gini in varying values of the conditioning variables ///
and then plotted the figure "by hand" using these numbers in MS EXCEL.


**********************************************************************************************
*THE END
**********************************************************************************************
